Phil Rickman Collection - 3 Books (Collection): 9781782399636
Description: Buy Phil Rickman Collection - 3 Books (Collection) - ISBN: 9781782399636 (978-1782399636) - Publisher: Atlantic Books from The Book People

What's New in Fiction
3
books
Just £2.00
per book!

### Product Details

- Product code: PHLR
- ISBN: 9781782399636
- Publisher: Atlantic Books
- Format: Collection
- Dimensions: 19.8cm x 13.1cm
- Pages: Varies
- Book points: 5

# Phil Rickman Collection - 3 Books (Collection)

##

- Books

Merrily Watkins is a country vicar and trainee exorcist - but she has to juggle these roles with being a single mother and helping to solve a local murder investigation.
The Wine of Angels finds Merrily arriving at her new picture-postcard parish. Much like her haunted vicarage, it's something she didn't wish for. While Merrily and her teenage daughter, Jane, delve into the history of Ledwardine, they realise it's a village steeped in murderous history.
Midwinter of the Spirit finds Merrily being offered the role of Deliverance Consultant (formerly Diocesan Exorcist). However, the role starts badly and gets no easier - a body is found in the River Wye, an ancient church is desecrated and signs of evil begin to appear in the cathedral... A Crown of Lights has a young pagan couple buying a redundant church - much to the fury of the local fundamentalist minister. As a modern witch hunt bubbles away in an isolated community on the Welsh border, Merrily is tasked with keeping a lid on the cauldron - but what she discovers will seriously test her beliefs.
You may have seen the ITV adaptation of Phil Rickman's Merrily Watkins series, also called Midwinter of the Spirit, but we reckon you'll enjoy the books even more.

Titles in this collection (3)

- Midwinter of the Spirit
- A Crown of Lights
- The Wine of Angels

### Product Details

- Product code: PHLR
- ISBN: 9781782399636
- Publisher: Atlantic Books
- Format: Collection
- Dimensions: 19.8cm x 13.1cm
- Pages: Varies
- Book points: 5

### Reviews

Help our customers make the best choices by telling everyone what you think about this product.

There are currently no customer reviews for this product. Why not be the first?

Rate & Review

- Our price £ 5.99
- RRP £26.97
- Save £20.98

Quantity

Add to wish list

### You have Book Points

Earn 5 points by adding this item to your basket or spend 350 points to get this item for FREE.

Sign in to spend points
More about Book Points